import * as _supabase_storage_js from '@supabase/storage-js';
import { FileObject, FileOptions } from '@supabase/storage-js';
import StorageFileApi from '@supabase/storage-js/dist/module/packages/StorageFileApi';

type DecodedStorageKey = {
    bucketId: string;
    path: string;
};
type StoragePrivacy = 'public' | 'private';

declare const fetchDirectory: (fileApi: StorageFileApi, path: string) => Promise<FileObject[]>;

type URLFetcher = (fileApi: StorageFileApi, path: string) => Promise<string | undefined>;
type URLFetcherConfig = {
    expiresIn?: number;
    ensureExistence?: boolean;
};
declare const createUrlFetcher: (mode: StoragePrivacy, config?: URLFetcherConfig) => URLFetcher;

type DirectoryURLsFetcher = (fileApi: StorageFileApi, path: string) => Promise<(FileObject & {
    url: string;
})[]>;
declare const createDirectoryUrlsFetcher: (mode: StoragePrivacy, config?: Pick<URLFetcherConfig, 'expiresIn'>) => DirectoryURLsFetcher;

type Cache<KeyType> = {
    /**
     * The keys currently present in the cache
     */
    cacheKeys: KeyType[];
    /**
     * Decode a key. Should return null if not a Storage key.
     */
    decode: (k: KeyType) => DecodedStorageKey | null;
    /**
     * The mutation function from the cache library
     */
    mutate: (key: KeyType) => Promise<void>;
};
declare const mutatePaths: <KeyType_1>(bucketId: string, paths: string[], { cacheKeys, decode, mutate }: Cache<KeyType_1>) => Promise<void>;

declare const createRemoveDirectoryFetcher: (fileApi: StorageFileApi) => (path: string) => Promise<_supabase_storage_js.FileObject[]>;

declare const createRemoveFilesFetcher: (fileApi: StorageFileApi) => (paths: string[]) => Promise<_supabase_storage_js.FileObject[]>;

type BuildFileNameFn = ({ path, fileName, }: {
    path?: string;
    fileName: string;
}) => string;
type UploadFetcherConfig = Partial<Pick<FileOptions, 'cacheControl' | 'upsert'>> & {
    buildFileName?: BuildFileNameFn;
};
type UploadFileResponse = Awaited<ReturnType<StorageFileApi['upload']>>;
type UploadFileInput = {
    data: Parameters<StorageFileApi['upload']>[1];
    type?: string;
    name: string;
};
type FileInput = File | UploadFileInput;
declare const createUploadFetcher: (fileApi: StorageFileApi, config?: UploadFetcherConfig) => (files: FileList | FileInput[], path?: string) => Promise<UploadFileResponse[]>;

export { BuildFileNameFn, Cache, DecodedStorageKey, FileInput, StoragePrivacy, URLFetcherConfig, UploadFetcherConfig, UploadFileInput, UploadFileResponse, createDirectoryUrlsFetcher, createRemoveDirectoryFetcher, createRemoveFilesFetcher, createUploadFetcher, createUrlFetcher, fetchDirectory, mutatePaths };
